@@ -400,74 +400,6 @@ verifyThresholdNames <- function(thresholds, observed, modelName=NA, observedThr
 	return(threshNames)
 }
 
-factorize <- function(x, levels, labels, exclude, collapse) {
-	x <- as.character(x)
-	if (length(exclude) && all(!is.na(exclude))) {
-		overlap <- match(exclude, levels)
-		if (any(!is.na(overlap))) {
-			msg <- paste("Factor levels and exclude vector are not disjoint; both contain",
-				     omxQuotes(levels[overlap]))
-			stop(msg)
-		}
-		x[which(!is.na(match(x, exclude)))] <- NA
-	}
-	noMatch <- !is.na(x) & is.na(match(x, levels))
-	if (any(noMatch)) {
-		msg <- paste("The following values are not mapped to factor levels and not excluded:",
-			     omxQuotes(unique(x[noMatch])))
-		stop(msg)
-	}
-	if (collapse) {
-    corder <- order(labels)
-    cLabels <- labels[corder]
-    cLevels <- levels[corder]
-	  dups <- duplicated(cLabels)
-	  newLevels <- cLevels[!dups]
-		notDup <- which(!dups)
-		for (dx in which(dups)) {
-			from <- cLevels[dx]
-			to <- newLevels[findInterval(dx, notDup)]
-			x[x==from] <- to
-		}
-    mask <- !duplicated(labels)
-		levels <- levels[mask]
-		labels <- labels[mask]
-	} else {
-	  dups <- duplicated(labels)
-	  if (any(dups)) stop(paste("Duplicate labels and collapse=TRUE not specified:",
-					  omxQuotes(unique(labels[dups]))))
-	}
-
-	f <- factor(x, levels, labels, exclude, ordered=TRUE)
-	attr(f, 'mxFactor') <- TRUE
-	f
-}
-
-mxFactor <- function(x = character(), levels, labels = levels, exclude = NA, ordered = TRUE, collapse=FALSE) {
-	if(missing(levels)) {
-		stop("the 'levels' argument is not optional")
-	}
-	if(!identical(ordered, TRUE)) {
-		stop("the 'ordered' argument must be TRUE")
-	}
-	if (is.data.frame(x)) {
-		if (is.list(levels)) {
-			return(data.frame(mapply(factorize, x, levels, labels,
-				MoreArgs=list(exclude = exclude, collapse=collapse), SIMPLIFY=FALSE),
-				check.names = FALSE, row.names=rownames(x)))
-		} else {
-			return(data.frame(lapply(x, factorize, levels, labels, exclude, collapse),
-				check.names = FALSE, row.names=rownames(x)))
-		}
-	} else if (is.matrix(x)) {
-		stop(paste("argument 'x' to mxFactor()",
-		"is of illegal type matrix,",
-		"legal types are vectors or data.frames"))
-	} else {
-		return(factorize(x, levels, labels, exclude, collapse))
-	}
-}
-
 
 displayThreshold <- function(object) {
 	cat("mxThreshold", '\n')
