@@ -59,10 +59,10 @@ omxCheckCloseEnough(testrunsumm$GREMLfixeff$se,
 
 
 plan <- mxComputeSequence(steps=list(
-  mxComputeNewtonRaphson(freeSet=c("Ve"),fitfunction="fitfunction"),
-  mxComputeOnce('fitfunction', c('fit','gradient','hessian','ihessian'),freeSet=c("Ve")),
-  mxComputeStandardError(freeSet=c("Ve")),
-  mxComputeReportDeriv(freeSet=c("Ve")),
+  mxComputeNewtonRaphson(fitfunction="fitfunction"),
+  mxComputeOnce('fitfunction', c('fit','gradient','hessian','ihessian')),
+  mxComputeStandardError(),
+  mxComputeReportDeriv(),
   mxComputeReportExpectation()
 ))
 
