@@ -115,11 +115,3 @@ omxCheckCloseEnough(mxEval(thresh, modelOut)[,1], Mx1Threshold[,1], 0.03)
 omxCheckCloseEnough(mxEval(thresh, modelOut)[1,2], Mx1Threshold[1,2], 0.01)
 omxCheckCloseEnough(mxEval(R, modelOut), Mx1R, 0.01)
 omxCheckCloseEnough(modelOut$output$Minus2LogLikelihood, 4081.48, 0.08)
-
-# Do something crazy
-
-dataMatrix$observed[[1]] <-
-  omxCheckWarning(ordered(dataMatrix$observed[[1]], levels=0:12, labels=c(0:11,3)),
-                  "duplicated levels in factors are deprecated")
-omxCheckError(mxRun(mxModel(model, dataMatrix, name="failModel")),
-              "Ordered factor column 't1neur1' in model 'failModel' has more than 1 level with the same name: '3'")
