@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2016 The OpenMx Project
+#   Copyright 2007-2017 The OpenMx Project
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -179,4 +179,24 @@ omxCheckCloseEnough(srun$A$values, dlmEstA, epsilon=0.001)
 omxCheckCloseEnough(srun$C$values[srun$C$free], dlmEstC, epsilon=0.001)
 omxCheckCloseEnough(diag(srun$R$values), dlmEstR, epsilon=0.001)
 
+if (.Platform$OS.type != 'windows' && detectCores() > 1) {
+  omxCheckTrue(srun$compute$steps[['GD']]$output$maxThreads > 1)
+}
+
+#------------------------------------------------------------------------------
+# Check computation of factor scores in backend
+# For an example that does not require a previously run model
+#  just use smod in place of srun in the line below.
+#  That would just compute factor scores from the starting values.
+smodf <- omxSetParameters(srun, free=FALSE, labels=names(coef(srun)))
+smodf <- mxModel(name='state space scoring', smodf,
+	mxExpectationStateSpace(A='A', B='B', C='C', D='D', Q='Q', R='R', x0='x', P0='P', u='u', scores=TRUE))
+
+srunf <- mxRun(smodf)
+
+ex <- srunf$expectation
+for (sl in c('xPredicted', 'xUpdated', 'xSmoothed', 'PPredicted', 'PUpdated', 'PSmoothed')) {
+  omxCheckTrue(all(dim(slot(ex,sl)) != c(0,0)))
+}
+
 
