@@ -1,5 +1,5 @@
 /*
-  Copyright 2012-2014, 2016 Joshua Nathaniel Pritikin and contributors
+  Copyright 2012-2017, 2016 Joshua Nathaniel Pritikin and contributors
 
   This is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -48,6 +48,7 @@ class ba81NormalQuad {
 	int gridSize;
 	std::vector<double> Qpoint;           // gridSize
 
+	// Currently, there is always only one layer.
 	class layer {
 	private:
 		template <typename T1, typename T2, typename T3, typename T4>
@@ -937,7 +938,9 @@ void BA81Engine<T, LatentPolicy, EstepPolicy>::ba81Estep1(class ifaGroup *state,
 	quad.allocBuffers(numThreads);
 	if (LatentPolicy<T>::wantSummary()) quad.allocSummary(numThreads);
 
+#if WANT_OPENMP
 #pragma omp parallel for num_threads(numThreads)
+#endif
 	for (int px=0; px < numUnique; px++) {
 		if (rowSkip[px]) {
 			patternLik[px] = 0;
@@ -966,10 +969,14 @@ void BA81Engine<T, LatentPolicy, EstepPolicy>::ba81Estep1(class ifaGroup *state,
 	}
 
 	if (EstepPolicy<T>::hasEnd() && LatentPolicy<T>::hasEnd()) {
+#if WANT_OPENMP
 #pragma omp parallel sections
+#endif
 		{
 			{ EstepPolicy<T>::recordTable(state); }
+#if WANT_OPENMP
 #pragma omp section
+#endif
 			{ LatentPolicy<T>::end(state, extraData); }
 		}
 	} else {
@@ -1006,21 +1013,13 @@ template <typename T1, typename T2, typename T3, typename T4>
 void ba81NormalQuad::layer::globalToLocalDist(Eigen::MatrixBase<T1> &gmean, Eigen::MatrixBase<T2> &gcov,
 					      Eigen::MatrixBase<T3> &mean, Eigen::MatrixBase<T4> &cov)
 {
-	// Refactor, I must have written this same code 3-4 times now TODO
+	struct subsetOp {
+		std::vector<bool> &abilitiesMask;
+		subsetOp(std::vector<bool> &abilitiesMask) : abilitiesMask(abilitiesMask) {};
+		bool operator()(int gx) { return abilitiesMask[gx]; };
+	} op(abilitiesMask);
 
-	mean.derived().resize(numAbil());
-	cov.derived().resize(numAbil(), numAbil());
-
-	for (int gcx=0, cx=0; gcx < gcov.cols(); gcx++) {
-		if (!abilitiesMask[gcx]) continue;
-		mean[cx] = gmean[gcx];
-		for (int grx=0, rx=0; grx < gcov.rows(); grx++) {
-			if (!abilitiesMask[grx]) continue;
-			cov(rx,cx) = gcov(grx, gcx);
-			rx += 1;
-		}
-		cx += 1;
-	}
+	subsetNormalDist(gmean, gcov, op, numAbil(), mean, cov);
 }
 
 template <typename T1, typename T2>
