@@ -929,7 +929,9 @@ void omxFIMLFitFunction::compute(int want, FitContext *fc)
 			omxFIMLFitFunction *ofo = getChildFIMLObj(fc, fitMatrix, tx);
 			ofo->skippedRows = 0;
 		}
+#if WANT_OPENMP
 #pragma omp parallel for num_threads(myParent->curParallelism) reduction(||:failed)
+#endif
 		for(int i = 0; i < myParent->curParallelism; i++) {
 			FitContext *kid = fc->childList[i];
 			omxMatrix *childMatrix = kid->lookupDuplicate(fitMatrix);
@@ -1057,7 +1059,8 @@ void omxFIMLFitFunction::init()
 
 	cov = omxGetExpectationComponent(expectation, "cov");
 	if(cov == NULL) { 
-		omxRaiseError("No covariance expectation in FIML evaluation.");
+		omxRaiseErrorf("%s: covariance not found in expectation '%s'",
+			       name(), expectation->name);
 		return;
 	}
 
@@ -1166,5 +1169,10 @@ void omxFIMLFitFunction::init()
         newObj->halfCov = omxInitMatrix(covCols, covCols, TRUE, off->matrix->currentState);
         newObj->reduceCov = omxInitMatrix(covCols, covCols, TRUE, off->matrix->currentState);
         omxCopyMatrix(newObj->ordContCov, newObj->cov);
+
+	if (!expectation->thresholdsMat) {
+		omxRaiseErrorf("%s: ordinal data found in %d columns but no thresholds",
+			 expectation->name, numOrdinal);
+	}
     }
 }
