@@ -21,12 +21,10 @@
 #include "libifa-rpf.h"
 #include "matrix.h"
 #include "omxBuffer.h"
+#include "Compute.h"
+#include "EnableWarnings.h"
 
-#ifdef SHADOW_DIAG
-#pragma GCC diagnostic warning "-Wshadow"
-#endif
-
-struct BA81FitState {
+struct BA81FitState : omxFitFunction {
 	//private:
 	void copyEstimates(BA81Expect *estate);
 	//public:
@@ -64,7 +62,9 @@ struct BA81FitState {
 	bool returnRowLikelihoods;
 
 	BA81FitState();
-	~BA81FitState();
+	virtual ~BA81FitState();
+	virtual void init();
+	virtual void compute(int ffcompute, FitContext *fc);
 };
 
 // writes to upper triangle of full matrix
@@ -93,9 +93,9 @@ void BA81FitState::copyEstimates(BA81Expect *estate)
 static void buildLatentParamMap(omxFitFunction* oo, FitContext *fc)
 {
 	FreeVarGroup *fvg = fc->varGroup;
-	BA81FitState *state = (BA81FitState *) oo->argStruct;
+	BA81FitState *state = (BA81FitState *) oo;
 	std::vector<int> &latentMap = state->latentMap;
-	BA81Expect *estate = (BA81Expect*) oo->expectation->argStruct;
+	BA81Expect *estate = (BA81Expect*) oo->expectation;
 	int maxAbilities = estate->grp.itemDims;
 
 	if (state->haveLatentMap == fc->varGroup->id[0]) return;
@@ -150,8 +150,8 @@ static void buildLatentParamMap(omxFitFunction* oo, FitContext *fc)
 static void buildItemParamMap(omxFitFunction* oo, FitContext *fc)
 {
 	FreeVarGroup *fvg = fc->varGroup;
-	BA81FitState *state = (BA81FitState *) oo->argStruct;
-	BA81Expect *estate = (BA81Expect*) oo->expectation->argStruct;
+	BA81FitState *state = (BA81FitState *) oo;
+	BA81Expect *estate = (BA81Expect*) oo->expectation;
 	std::vector<const double*> &itemSpec = estate->grp.spec;
 
 	if (state->haveItemMap == fc->varGroup->id[0]) return;
@@ -297,8 +297,8 @@ static double
 ba81ComputeEMFit(omxFitFunction* oo, int want, FitContext *fc)
 {
 	const double Scale = Global->llScale;
-	BA81FitState *state = (BA81FitState*) oo->argStruct;
-	BA81Expect *estate = (BA81Expect*) oo->expectation->argStruct;
+	BA81FitState *state = (BA81FitState*) oo;
+	BA81Expect *estate = (BA81Expect*) oo->expectation;
 	omxMatrix *itemParam = estate->itemParam;
 	std::vector<const double*> &itemSpec = estate->grp.spec;
 	ba81NormalQuad &quad = estate->getQuad();
@@ -329,7 +329,9 @@ ba81ComputeEMFit(omxFitFunction* oo, int want, FitContext *fc)
 	if (do_deriv) {
 		thrDeriv.resize(thrDerivSize * Global->numThreads);
 
+#if WANT_OPENMP
 #pragma omp parallel for num_threads(Global->numThreads)
+#endif
 		for (int ix=0; ix < numItems; ix++) {
 			int thrId = omx_absolute_thread_num();
 			double *myDeriv = thrDeriv.data() + thrDerivSize * thrId + ix * state->itemDerivPadSize;
@@ -395,6 +397,7 @@ ba81ComputeEMFit(omxFitFunction* oo, int want, FitContext *fc)
 		}
 	}
 
+	fc->skippedRows += excluded;
 	if (excluded && estate->verbose >= 1) {
 		mxLog("%s: Hessian not positive definite for %d/%d items",
 		      oo->name(), (int) excluded, (int) numItems);
@@ -512,8 +515,8 @@ static void sandwich(omxFitFunction *oo, FitContext *fc)
 {
 	const double abScale = fabs(Global->llScale);
 	omxExpectation *expectation = oo->expectation;
-	BA81FitState *state = (BA81FitState*) oo->argStruct;
-	BA81Expect *estate = (BA81Expect*) expectation->argStruct;
+	BA81FitState *state = (BA81FitState*) oo;
+	BA81Expect *estate = (BA81Expect*) expectation;
 	if (estate->verbose >= 1) mxLog("%s: sandwich", oo->name());
 
 	omxMatrix *itemParam = estate->itemParam;
@@ -535,7 +538,9 @@ static void sandwich(omxFitFunction *oo, FitContext *fc)
 
 	quad.allocBuffers(numThreads);
 
+#if WANT_OPENMP
 #pragma omp parallel for num_threads(numThreads)
+#endif
 	for (int px=0; px < numUnique; px++) {
 		if (rowSkip[px]) continue;
 		int thrId = omx_absolute_thread_num();
@@ -597,8 +602,8 @@ static void sandwich(omxFitFunction *oo, FitContext *fc)
 
 static void setLatentStartingValues(omxFitFunction *oo, FitContext *fc) //remove? TODO
 {
-	BA81FitState *state = (BA81FitState*) oo->argStruct;
-	BA81Expect *estate = (BA81Expect*) oo->expectation->argStruct;
+	BA81FitState *state = (BA81FitState*) oo;
+	BA81Expect *estate = (BA81Expect*) oo->expectation;
 	std::vector<int> &latentMap = state->latentMap;
 	ba81NormalQuad &quad = estate->getQuad();
 	int maxAbilities = quad.abilities();
@@ -674,8 +679,8 @@ static void gradCov(omxFitFunction *oo, FitContext *fc)
 {
 	const double Scale = Global->llScale;
 	omxExpectation *expectation = oo->expectation;
-	BA81FitState *state = (BA81FitState*) oo->argStruct;
-	BA81Expect *estate = (BA81Expect*) expectation->argStruct;
+	BA81FitState *state = (BA81FitState*) oo;
+	BA81Expect *estate = (BA81Expect*) expectation;
 	if (estate->verbose >= 1) mxLog("%s: cross product approximation", oo->name());
 
 	omxMatrix *itemParam = estate->itemParam;
@@ -711,7 +716,9 @@ static void gradCov(omxFitFunction *oo, FitContext *fc)
 
 	quad.allocBuffers(numThreads);
 
+#if WANT_OPENMP
 #pragma omp parallel for num_threads(numThreads)
+#endif
 	for (int px=0; px < numUnique; px++) {
 		if (rowSkip[px]) continue;
 		int thrId = omx_absolute_thread_num();
@@ -792,11 +799,11 @@ static void gradCov(omxFitFunction *oo, FitContext *fc)
 	}
 }
 
-static void
-ba81ComputeFit(omxFitFunction* oo, int want, FitContext *fc)
+void BA81FitState::compute(int want, FitContext *fc)
 {
-	BA81FitState *state = (BA81FitState*) oo->argStruct;
-	BA81Expect *estate = (BA81Expect*) oo->expectation->argStruct;
+	auto *oo = this;
+	BA81FitState *state = (BA81FitState*) this;
+	BA81Expect *estate = (BA81Expect*) oo->expectation;
 	if (fc) state->numFreeParam = fc->varGroup->vars.size();
 
 	if (want & (FF_COMPUTE_INITIAL_FIT | FF_COMPUTE_FINAL_FIT)) return;
@@ -889,17 +896,19 @@ ba81ComputeFit(omxFitFunction* oo, int want, FitContext *fc)
 				double *rowWeight = estate->grp.rowWeight;
 				const double LogLargest = estate->LogLargestDouble;
 				double got = 0;
+#if WANT_OPENMP
 #pragma omp parallel for num_threads(Global->numThreads) reduction(+:got)
+#endif
 				for (int ux=0; ux < numUnique; ux++) {
 					if (patternLik[ux] == 0) continue;
 					got += rowWeight[ux] * (log(patternLik[ux]) - LogLargest);
 				}
 				double fit = nan("infeasible");
 				if (estate->grp.excludedPatterns < numUnique) {
-					fit = Global->llScale * got;
-					// add in some badness for excluded patterns
-					fit += fit * estate->grp.excludedPatterns;
+					fit = addSkippedRowPenalty(got, estate->grp.excludedPatterns);
+					fit *= Global->llScale;
 				}
+				fc->skippedRows += estate->grp.excludedPatterns;
 				if (estate->verbose >= 1) mxLog("%s: observed fit %.4f (%d/%d excluded)",
 								oo->name(), fit, estate->grp.excludedPatterns, numUnique);
 				oo->matrix->data[0] = fit;
@@ -910,12 +919,6 @@ ba81ComputeFit(omxFitFunction* oo, int want, FitContext *fc)
 	}
 }
 
-static void ba81Compute(omxFitFunction *oo, int want, FitContext *fc)
-{
-	if (!want) return;
-	ba81ComputeFit(oo, want, fc);
-}
-
 BA81FitState::~BA81FitState()
 {
 	omxFreeMatrix(itemParam);
@@ -923,27 +926,18 @@ BA81FitState::~BA81FitState()
 	omxFreeMatrix(latentCov);
 }
 
-static void ba81Destroy(omxFitFunction *oo) {
-	BA81FitState *state = (BA81FitState *) oo->argStruct;
-	delete state;
-}
+omxFitFunction *omxInitFitFunctionBA81()
+{ return new BA81FitState; }
 
-void omxInitFitFunctionBA81(omxFitFunction* oo)
+void BA81FitState::init()
 {
-	if (!oo->argStruct) { // ugh!
-		BA81FitState *state = new BA81FitState;
-		oo->argStruct = state;
-	}
+	auto *oo = this;
+	auto *state = this;
 	omxState *currentState = oo->matrix->currentState;
-	BA81FitState *state = (BA81FitState*) oo->argStruct;
 
-	omxExpectation *expectation = oo->expectation;
-	BA81Expect *estate = (BA81Expect*) expectation->argStruct;
+	BA81Expect *estate = (BA81Expect*) expectation;
 	estate->fit = oo;
 
-	oo->computeFun = ba81Compute;
-	oo->setVarGroup = ba81SetFreeVarGroup;
-	oo->destructFun = ba81Destroy;
 	oo->gradientAvailable = TRUE;
 	oo->hessianAvailable = TRUE;
 
@@ -965,4 +959,6 @@ void omxInitFitFunctionBA81(omxFitFunction* oo)
 	state->copyEstimates(estate);
 
 	state->returnRowLikelihoods = Rf_asInteger(R_do_slot(oo->rObj, Rf_install("vector")));
+
+	units = returnRowLikelihoods? FIT_UNITS_PROBABILITY : FIT_UNITS_MINUS2LL;
 }
