@@ -241,7 +241,9 @@ void omxComputeNumericDeriv::doHessianCalculation(int numChildren, struct hess_s
 	}
 
 	if (numChildren) {
+#if WANT_OPENMP
 #pragma omp parallel for num_threads(parallelism)
+#endif
 		for(int i = 0; i < numParams; i++) {
 			if (hessian && std::isfinite(hessian[i*numParams + i])) continue;
 			int threadId = (numChildren < 2) ? 0 : omx_absolute_thread_num();
@@ -250,7 +252,9 @@ void omxComputeNumericDeriv::doHessianCalculation(int numChildren, struct hess_s
 
 		reportProgress(hess_work->fc);
 
+#if WANT_OPENMP
 #pragma omp parallel for num_threads(parallelism)
+#endif
 		for(int i = 0; i < int(todo.size()); i++) {
 			int threadId = (numChildren < 2) ? 0 : omx_absolute_thread_num();
 			omxEstimateHessianOffDiagonal(todo[i].first, todo[i].second, hess_work + threadId);
@@ -462,19 +466,18 @@ void omxComputeNumericDeriv::computeImpl(FitContext *fc)
 	}
 
 	Eigen::Map< Eigen::ArrayXi > Gsymmetric(LOGICAL(VECTOR_ELT(detail, 0)), numParams);
-	Eigen::ArrayXi Gsmall(numParams);
-	double gradThresh = Global->getGradientThreshold(minimum);
+	double gradNorm = 0.0;
+	
 	double feasibilityTolerance = Global->feasibilityTolerance;
 	for (int px=0; px < numParams; ++px) {
 		// factor out simliar code in ComputeNR
 		omxFreeVar &fv = *fc->varGroup->vars[px];
 		if ((fabs(optima[px] - fv.lbound) < feasibilityTolerance && Gc[px] > 0) ||
 		    (fabs(optima[px] - fv.ubound) < feasibilityTolerance && Gc[px] < 0)) {
-			Gsmall[px] = true;
 			Gsymmetric[px] = false;
 			continue;
 		}
-		Gsmall[px] = fabs(Gc[px]) < gradThresh;
+		gradNorm += Gc[px] * Gc[px];
 		double relsym = 2 * fabs(Gf[px] + Gb[px]) / (Gb[px] - Gf[px]);
 		Gsymmetric[px] = (Gf[px] < 0 && 0 < Gb[px] && relsym < 1.5);
 		if (checkGradient && verbose >= 2 && !Gsymmetric[px]) {
@@ -485,9 +488,11 @@ void omxComputeNumericDeriv::computeImpl(FitContext *fc)
 	fc->grad.resize(numParams);
 	fc->grad = Gc.matrix();
 
-	if (checkGradient && !Gsmall.all()) {
+	gradNorm = sqrt(gradNorm);
+	double gradThresh = Global->getGradientThreshold(minimum);
+	if (checkGradient && gradNorm > gradThresh) {
 		if (verbose >= 1) {
-			mxLog("Some gradient entries are too large, norm %f", Gc.matrix().norm());
+			mxLog("Some gradient entries are too large, norm %f", gradNorm);
 		}
 		if (fc->getInform() < INFORM_NOT_AT_OPTIMUM) fc->setInform(INFORM_NOT_AT_OPTIMUM);
 	}
