@@ -19,14 +19,11 @@
 #include "omxState.h"
 #include "omxNPSOLSpecific.h"
 #include "omxMatrix.h"
-#include "glue.h"
 #include "omxImportFrontendState.h"
 #include "Compute.h"
+#include "ComputeGD.h"
 #include "npsolswitch.h"
-
-#ifdef SHADOW_DIAG
-#pragma GCC diagnostic warning "-Wshadow"
-#endif
+#include "EnableWarnings.h"
 
 template <typename T1, typename T2, typename T3>
 void GradientOptimizerContext::allConstraintsFun(Eigen::MatrixBase<T1> &constraintOut, Eigen::MatrixBase<T2> &jacobianOut, 
@@ -180,19 +177,6 @@ void GradientOptimizerContext::linearConstraintCoefficients(Eigen::MatrixBase<T1
 	}
 }
 
-void GradientOptimizerContext::checkForAnalyticJacobians()
-{
-	usingAnalyticJacobian = false;
-	omxState *st = fc->state;
-	for(int i=0; i < (int) st->conListX.size(); i++){
-		omxConstraint &cs = *st->conListX[i];
-		if(cs.jacobian){
-			usingAnalyticJacobian = true;
-			return;
-		}
-	}
-}
-
 static double getNPSOLFeasibilityTolerance()
 {
 	// convert units (who knows what the units are)
